@@ -38,6 +38,7 @@ if(getRversion() >= "2.15.1"){
 #'  fill variable stratum, Default: TRUE
 #'@param verbose logical, print plot summary, Default: F
 #'@param stratum_labels logical, Default: TRUE
+#'@param stratum_label_type character, Default: "label"
 #'@param stratum_label_size numeric, Default: 4.5
 #'@param stratum_width double, Default: 1/4
 #'@param auto_rotate_xlabs logical, Default: TRUE
@@ -98,6 +99,7 @@ alluvial_wide = function( data
                             , colorful_fill_variable_stratum = T
                             , verbose = F
                             , stratum_labels = T
+                            , stratum_label_type = "label"
                             , stratum_label_size = 4.5
                             , stratum_width = 1/4
                             , auto_rotate_xlabs = T
@@ -367,8 +369,13 @@ alluvial_wide = function( data
     labs( x = '', y = 'count', caption = caption)
 
   if(stratum_labels){
-    p = p + geom_label( stat = ggalluvial::StatStratum
-                        , size = stratum_label_size )
+    if(stratum_label_type == "label"){
+        p = p + geom_label( stat = ggalluvial::StatStratum
+                            , size = stratum_label_size )
+    } else if (stratum_label_type == "text"){
+        p = p + geom_text( stat = ggalluvial::StatStratum
+                            , size = stratum_label_size )
+    }
   }
 
   # angle x labels------------------------------------
@@ -388,7 +395,7 @@ alluvial_wide = function( data
 
     data_key = data_new %>%
       mutate( alluvial_id = manip_factor_2_numeric(alluvial_id) ) %>%
-      left_join( data_alluvial ) %>%
+      left_join( data_alluvial, relationship = "many-to-many" ) %>%
       select( - fill_flow, -fill_value, -fill ) %>%
       spread( key = x, value = value ) %>%
       select( one_of(id_str, variables, 'alluvial_id', 'n' ) ) %>%
